import { createContext, ReactNode, useContext, useState } from "react";

interface ProjectState {
  projectId: string;
}

interface ProjectContextType extends ProjectState {
  setProjectId: (v: string) => void;
}

export const PROJECT_CONTEXT_INITIAL_STATE: ProjectContextType = {
  projectId: import.meta.env.VITE_CAIRO_PROJECT as string,
  setProjectId: () => void 0,
};

const ProjectContext = createContext<ProjectContextType>(PROJECT_CONTEXT_INITIAL_STATE);

export const useProjectContext = () => useContext<ProjectContextType>(ProjectContext);

export const ProjectProvider = ({ children }: { children: ReactNode }) => {
  const [projectId, setProjectId] = useState<string>(PROJECT_CONTEXT_INITIAL_STATE.projectId);

  const context: ProjectContextType = {
    projectId,
    setProjectId,
  };

  return <ProjectContext.Provider value={context}>{children}</ProjectContext.Provider>;
};
